django-aws-api-gateway-websockets
=================================

.. toctree::
   :maxdepth: 4

   django_aws_api_gateway_websockets
   make_migrations
   make_migrations_settings
   setup
   tests
